==> estateplat-common-1.2.3-20180109.015111-8-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtCheckinfo.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * .
 * <p/>
 * 系统验证信息配置表
 * lst
 *
 * @version V1.0, 15-3-31
 */
@Table(name = "bdc_xt_checkinfo")
public class BdcXtCheckinfo implements Serializable {
    @Id
    private String id;
    private String sqlxdm;
    private String qllxdm;
    private Integer checkCode;//验证业务逻辑代码
    private String checkModel;//验证模式 alert  confirm
    private String checkMsg;//验证提示信息
    private String ysqlxdm;//原申请类型代码
    private String createSqlxdm; //当checkModel为confirmAndCreate时，创建的申请类型代码
    private String checkType;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSqlxdm() {
        return sqlxdm;
    }

    public void setSqlxdm(String sqlxdm) {
        this.sqlxdm = sqlxdm;
    }

    public String getQllxdm() {
        return qllxdm;
    }

    public void setQllxdm(String qllxdm) {
        this.qllxdm = qllxdm;
    }

    public Integer getCheckCode() {
        return checkCode;
    }

    public void setCheckCode(Integer checkCode) {
        this.checkCode = checkCode;
    }

    public String getCheckModel() {
        return checkModel;
    }

    public void setCheckModel(String checkModel) {
        this.checkModel = checkModel;
    }

    public String getCheckMsg() {
        return checkMsg;
    }

    public void setCheckMsg(String checkMsg) {
        this.checkMsg = checkMsg;
    }

    public String getYsqlxdm() {
        return ysqlxdm;
    }

    public void setYsqlxdm(String ysqlxdm) {
        this.ysqlxdm = ysqlxdm;
    }

    public String getCreateSqlxdm() {
        return createSqlxdm;
    }

    public void setCreateSqlxdm(String createSqlxdm) {
        this.createSqlxdm = createSqlxdm;
    }

    public String getCheckType() {
        return checkType;
    }

    public void setCheckType(String checkType) {
        this.checkType = checkType;
    }
}

==> estateplat-common-1.2.4-20210326.012715-681-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtCheckinfo.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * .
 * <p/>
 * 系统验证信息配置表
 * lst
 *
 * @version V1.0, 15-3-31
 */
@Table(name = "bdc_xt_checkinfo")
public class BdcXtCheckinfo implements Serializable {
    @Id
    private String id;
    private String sqlxdm;
    private String qllxdm;
    private Integer checkCode;//验证业务逻辑代码
    private String checkModel;//验证模式 alert  confirm
    private String checkMsg;//验证提示信息
    private String ysqlxdm;//原申请类型代码
    private String createSqlxdm; //当checkModel为confirmAndCreate时，创建的申请类型代码
    private String checkType;
    private String yzly; //验证来源

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSqlxdm() {
        return sqlxdm;
    }

    public void setSqlxdm(String sqlxdm) {
        this.sqlxdm = sqlxdm;
    }

    public String getQllxdm() {
        return qllxdm;
    }

    public void setQllxdm(String qllxdm) {
        this.qllxdm = qllxdm;
    }

    public Integer getCheckCode() {
        return checkCode;
    }

    public void setCheckCode(Integer checkCode) {
        this.checkCode = checkCode;
    }

    public String getCheckModel() {
        return checkModel;
    }

    public void setCheckModel(String checkModel) {
        this.checkModel = checkModel;
    }

    public String getCheckMsg() {
        return checkMsg;
    }

    public void setCheckMsg(String checkMsg) {
        this.checkMsg = checkMsg;
    }

    public String getYsqlxdm() {
        return ysqlxdm;
    }

    public void setYsqlxdm(String ysqlxdm) {
        this.ysqlxdm = ysqlxdm;
    }

    public String getCreateSqlxdm() {
        return createSqlxdm;
    }

    public void setCreateSqlxdm(String createSqlxdm) {
        this.createSqlxdm = createSqlxdm;
    }

    public String getCheckType() {
        return checkType;
    }

    public void setCheckType(String checkType) {
        this.checkType = checkType;
    }

    public String getYzly() {
        return yzly;
    }

    public void setYzly(String yzly) {
        this.yzly = yzly;
    }
}
